{{-- @extends('layouts.app') --}}
@extends('layouts.sidebar')

@section('content')
    {{-- {{$contactos}} --}}
    <div class="container">
        {{-- {{$repuestos_medidas}} --}}

        <form id="formulario_principal" action="{{ route('ordendetrabajo.manualstore') }}" method="POST" onsubmit="return validarFormulario()">
            @csrf
            {{-- Session 1 --}}
            <div class="row card mb-2" id="datosequipo" style="display: ">
                <div class="card-header">
                    Datos del motor
                </div>

                <div class="card-body">

                    {{-- <div class="container"> --}}
                      
                        <div class="row">
                            @if (\App\Models\User::tipoUsuario() == 'superadmin' || \App\Models\User::tipoUsuario() == 'admin')

                                    <div class="mb-3 col-6">
                                        <label for="" class="form-label">Sucursal</label>
                                        <select  onchange="cambioDeInputOnchange(this, 'equipo_modelo')" class="form-control mayuscula" name="sucursal" id="sucursal">
                                            <option value="">Seleccionar</option>
                                            @if (!empty($sucursales))
                                                @foreach ($sucursales as $data)
                                                    <option value="{{ $data->id }}"
                                                        {{ old('sucursal') == $data->id ? 'selected' : '' }}>
                                                        {{ $data->descripcion }}
                                                    </option>
                                                @endforeach
                                            @endif
                                        </select>

                                    </div>

                                    <div class="mb-3 col-6"></div>
                            
                            @endif



                            <div class="col-md ">
                                <label for="">Modelo</label>
                                <input type="text"  onkeydown="cambioDeInput(event,'equipo_marca')"  id="equipo_modelo"  name="equipo_modelo" class="form-control mt-2"
                                    value="">
                            </div>
                                {{-- <div class="col-md m-2">
                                <label for="">Patente</label>
                                <input type="text" id="equipo_patente" name="equipo_patente" class="form-control" value="">
                            </div> --}}
                            <div class="col-md mt-2">
                                <label for="">Marca</label>
                                <input type="text"  onkeydown="cambioDeInput(event,'equipo_motor')"  id="equipo_marca" name="equipo_marca" class="form-control"
                                    value="">
                            </div>
                            <div class="col-md mt-2">
                                <label for="">Motor</label>
                                <input type="text" onkeydown="cambioDeInput(event,'equipo_ano')"  id="equipo_motor" name="equipo_motor" class="form-control"
                                    value="">
                            </div>
                            <div class="row">


                                <div class="col-md mt-2">
                                    <label for="">Año</label>
                                    <input type="text" onkeydown="cambioDeInput(event,'equipo_serie')"  id="equipo_ano" name="equipo_ano" class="form-control"
                                        value="">
                                </div>
                                <div class="col-md mt-2">
                                    <label for="">Serie</label>
                                    <input type="text" onkeydown="cambioDeInput(event,'equipo_combustible')"  id="equipo_serie" name="equipo_serie"class="form-control"
                                        value="">
                                </div>
                                <div class="col-md mt-2">
                                    <label for="">Combustible</label>
                                    <select class="form-control mayuscula" id="equipo_combustible" name="combustible"
                                        id="combustible">
                                        <option value="">Seleccionar</option>
                                        @if (!empty($combustibles))
                                            @foreach ($combustibles as $data)
                                                <option value="{{ $data->id }}">
                                                    {{ $data->nombre }}</option>
                                            @endforeach
                                        @endif
                                    </select>
                                </div>

                                <div class="col-md mt-2">
                                    <label for="">Chofer</label>
                                    {{-- <input type="checkbox" name="movil" id="movil"> --}}


                                       @if (\App\Models\User::tipoUsuario() == 'superadmin' || \App\Models\User::tipoUsuario() == 'admin')

                                       <select class="form-control mayuscula" style="display: " id="equipo_chofer" 
                                            name="choferselect" id="choferselect">
                                            <option value="">Seleccionar</option>
                                           
                                       </select>

                                        @else
                                                <select class="form-control mayuscula" style="display: " id="equipo_chofer" 
                                                name="choferselect" id="choferselect">
                                                <option value="">Seleccionar</option>
                                                @if (!empty($datosChofer))
                                                    @foreach ($datosChofer as $data)
                                                        <option value="{{ $data->id_user }}">
                                                            {{ $data->nombre }} {{ $data->apellido }}</option>
                                                    @endforeach
                                                @endif
                                            </select>


                                        @endif

                                  
                                </div>
                            </div>
                        </div>
                    </div>

                {{-- </div> --}}



                {{-- <div style="text-align: right">
                    <input type="button" value="Siguiente" onclick="siguiente(1)" class="m-2">
                </div> --}}
            </div> {{-- fin del card --}}


            {{-- Session 2 --}}
            <div class="row card" id="servivioyrepuestos" style="display:">
                <div class="card-header">
                    Servicios y Repuestos
                </div>

                <div class="card-body">


                    <div class="row">
                        @if (\App\Models\User::tipoUsuario() == 'superadmin' || \App\Models\User::tipoUsuario() == 'admin')

                           

                            <div class="mb-3 col-12" id="">
                                <label for="" class="form-label">Operario encargado</label>
                                <div id="operario"></div>

                                {{-- <select class="form-control mayuscula" name="operario" id="operario">
                                    <option value="">Seleccionar</option> --}}
                                    {{-- @if (!empty($operarios))
                                @foreach ($operarios as $data)
                                    <option value="{{ $data->id_user }}"
                                        {{ old('operario') == $data->id_user ? 'selected' : '' }}>{{ $data->nombre }}
                                        {{ $data->apellido }}</option>
                                @endforeach
                            @endif --}}
                                {{-- </select> --}}

                            </div>
                        @else

                        <div class="mb-3 col-12">
                            <label class="form-label">Operarios encargados</label>
                        
                            <div class="d-flex">
                                @if (!empty($operarios))
                                @foreach ($operarios as $key => $data)
                                <div class="form-check me-3">
                                    <input class="form-check-input" type="radio" name="operario" id="operario{{ $data->id_user }}"
                                           value="{{ $data->id_user }}" {{ $key === 0 ? 'checked' : '' }}>
                                    <label class="form-check-label" for="operario{{ $data->id_user }}">
                                        {{ $data->nombre }} {{ $data->apellido }}
                                    </label>
                                </div>
                            @endforeach
                            
                                @endif
                            </div>
                        </div>
                            {{-- <div class="mb-3 col-6">
                                <label for="" class="form-label">Operario encargado</label>
                                <select class="form-control mayuscula" name="operario" id="operario">
                                    <option value="">Seleccionar</option>
                                    @if (!empty($operarios))
                                        @foreach ($operarios as $data)
                                            <option value="{{ $data->id_user }}"
                                                {{ old('operario') == $data->id_user ? 'selected' : '' }}>
                                                {{ $data->nombre }}
                                                {{ $data->apellido }}</option>
                                        @endforeach
                                    @endif
                                </select>

                            </div> --}}
                        @endif





                        <div class="mb-3 col-3">
                            <label for="" class="form-label">Fecha entrega (estimada)</label>
                            <input  type="date" value="{{ $cliente[0]->fecha_entrega ?? '' }}" class="form-control"
                                id="fecha_entrega" placeholder="" name="fecha_entrega">
                        </div>



                        <div class="col-12 form-group">
                            <div class="d-flex align-items-center">
                                <h5 for="">Servicio</h5>
                                <a style="cursor: pointer" data-bs-toggle="modal" data-bs-target="#modalSelectServicios"> <span class="material-symbols-outlined">
                                    search
                                </span></a> 
                                   

                                
                            </div>
                           <div class="row mb-3" >
                            <div class="col">
                                <label for="">Sku</label>
                                <input type="text" class="form-control mayuscula" id="campoServicio" placeholder="Servicio" name="servicio" value="" onkeydown="buscarServicioFunction(event)">
                            </div>
                            <div class="col">
                                <label for="">Nombre servicio</label>
                                
                                <input type="text" disabled class="form-control mayuscula" id="nombredelservicio" >
                            </div>
                               <div class="col">
                                <label for="">Descripción</label>

                                <input type="text" class="form-control mayuscula" id="campoServicioDescripcion" placeholder="Descripcion" name="servicio" value="" onkeydown="buscarServicioFunctionDesc(event)">

                               </div>
                               <div class="col">
                                <label for="">Cantidad</label>

                                <input type="text" class="form-control mayuscula" onkeypress='soloNumeros(event)' id="campoServicioCantidad" placeholder="Cantidad" name="servicio" value="" onkeydown="buscarServicioFunctionCan(event)">

                               </div>
                               {{-- <div class="col">
                                <input type="" class="form-control mayuscula" id=""
                                placeholder="Servicio" name="" value="">
                               </div> --}}
                           </div>


                                <span id="faltaServicio" style="display: none"><label for="" style="color: red">Debe seleccionar almenos un servicio</label></span>
                        </div><br><br>
                       
                        {{-- <div class="col-12 form-group">
                            <h5 for="">Servicio</h5>
                            <input type="" class="form-control mayuscula" id="nombre_servicio"
                                placeholder="Servicio" name="" value="">
                                <span id="faltaServicio" style="display: none"><label for="" style="color: red">Debe seleccionar almenos un servicio</label></span>
                        </div>
                        <div class="col-12 form-group" id="">
                            <table class="table table-hover">
                                <tbody id="tableservicios"></tbody>
                            </table>
                        </div> --}}

                        <br>
                        <div>
                            <table class="table table-hover">
                                <thead class="bg-light">
                                    <th scope="col">Codigo</th>
                                    <th scope="col">Servicios</th>
                                    <th scope="col">Descripcion </th>
                                    <th scope="col">Categoria</th>
                                    
                                    <th scope="col">Cantidad</th>

                                    <th scope="col">Neto</th>
                                    {{-- <th scope="col">Descuento</th> --}}
                                    <th scope="col">Total</th>

                                    <th scope="col">Acciones</th>


                                </thead>

                                <tbody id="tabla_servicios_selecionados">

                                </tbody>
                            </table>
                            <input type="text"  hidden id="arrayDatosTabla" name="arrayDatosTabla">
                        </div>

                    </div>{{-- fin del row --}}
                    <hr>

                    <div class="row">

                        <div class="col-12 form-group">
                            <h5 for="">Repuestos solicitados</h5>
                            {{-- <input type="" class="form-control mayuscula" id="nombre_repuesto"
                                placeholder="Repuestos solicitados" name="" value=""> --}}
                                {{-- {{$repuestos}} --}}

                                @foreach ($repuestos as $data)

                               {{-- <div>
                                <input type="checkbox" name="" id="" value="{{$data->nombre}}">{{$data->nombre}}
                               </div> --}}
                               <div style="display: inline-block; margin-right: 20px;">
                                <input type="checkbox" name="" onclick="actualizarTable({{$data->id}})" id="check_{{$data->id}}" value="{{$data->nombre}}">
                                <label style="cursor: pointer"  for="check_{{$data->id}}">{{$data->nombre}}</label>
                            </div>
                                @endforeach
                        </div>
                        <div class="col-12 form-group" id="">
                            <table class="table table-hover">
                                <tbody id="tablerepuestos"></tbody>
                            </table>
                        </div>


                        <div>
                            <table class="table table-hover">
                                <thead class="bg-light">
                                    <th scope="col">Repuesto</th>
                                    <th scope="col">Medidas</th>

                                    <th scope="col">Categoria</th>
                                    
                                    <th scope="col">Cantidad</th>


                                    <th scope="col">Acciones</th>


                                </thead>

                                <tbody id="tabla_repuesto_selecionados">

                                </tbody>
                            </table>
                            <input type="" hidden  id="arrayDatosTablaRepuestos" name="arrayDatosTablaRepuestos">
                        </div>

                    </div>{{-- fin del row --}}
                    <hr>
                    <div class="row">
                        <div class="mb-3 col-13">
                            <label for="" class="form-label">Comentario</label>

                            <textarea name="comentario" class="form-control" id="idcomentario" cols="3" rows="3" maxlength="300"></textarea>

                        </div>
                    </div>



                    <br>
                    <br>
                    <hr>
                    <br>

                    <div class="row">
                        <h4>Datos Pago</h4>

                        <div>
                            <strong> <label for="">Sub Total:</label> </strong> <label for=""
                                id="l_subtotal"></label>
                        </div>
                        <div>
                            <strong> <label for="">Impuesto:</label> </strong> <label for=""
                                id="l_impuestoTotal"></label>
                        </div>
                        <div>
                            <label for="" style="font-weight: bold; color: black;">Total:</label>
                            <label style="font-weight: bold; color: black;" for="" id="l_totalmasimpuesto"></label>
                          </div>

                        <div>
                            <strong>
                                <label for="">Descuento(%):
                                    <a data-bs-toggle="modal" data-bs-target="#modalDescuento">
                                        <span class="material-symbols-outlined">
                                            edit
                                        </span>
                                    </a>

                                </label>
                            </strong>
                            <label for="" id="l_descuento"></label>
                        </div>
                        <div>
                            <strong>
                                <label for="">Descuento($):
                                    <a data-bs-toggle="modal" data-bs-target="#modalDescuentoTotal">
                                        <span class="material-symbols-outlined">
                                            edit
                                        </span>
                                    </a>

                                </label>
                            </strong>
                            <label for="" id="l_descuento_sin_porcentaje"></label>
                        </div>
                       
                        <div>
                            <strong> <label style="color: red"  for="">Neto:</label> </strong> <label  for=""
                                id="l_totalnetoNuevo"></label>
                        </div>
                        <div >
                            <strong> <label style="color: red" for="">Impuesto:</label> </strong> <label for=""
                                id="l_impuestoTotalNuevo"></label>
                        </div>
                        <div>
                            <strong> <label style="font-weight: bold; color: black;" for="">Total con descuento:</label> </strong> <label style="font-weight: bold; color: black;" for=""
                                id="l_totalcondescuento"></label>
                        </div>
                      
                       
                        {{-- <div>
                        <strong> <label for="">Descuento total:</label> </strong> <label for=""
                            id="l_descuentoTotal"></label>
                    </div> --}}
                        <div>
                            <strong>
                                <label for="">Abono:</label>
                                <a data-bs-toggle="modal" data-bs-target="#modalAbono">
                                    <span class="material-symbols-outlined">
                                        edit
                                    </span>
                                </a>
                            </strong>
                            <label for="" id="l_abono"></label>
                        </div>

                        <div>
                            <strong> <label for="">Pendiente:</label> </strong> <label for=""
                                id="l_pendiente"></label>
                        </div>
                    </div>{{-- fin del row --}}



                    {{-- DATOS POR ENVIAR --}}
                    <input type="text" hidden name="input_abono" id="input_abono">
                    <input type="text" hidden name="input_descuento" id="input_descuento">
                    <input type="text" hidden name="input_metodopago" id="input_metodopago">





                    <div style="text-align: right">
                        <input type="button" value="Atras" onclick="atras(1)" class="m-2">

                        <input type="button" value="Siguiente" onclick="siguiente(2)" class="m-2">
                    </div>
                </div> {{-- fin del card  session 3 --}}

            </div>

            {{-- Session 3 --}}
            <div class="row card" id="datoscontactose" style="display:none">
                <div class="card-header">
                    Datos del Contacto
                </div>

                <div class="card-body">
                    <div class="col-md m-2"> <label for="">Contacto</label>
                        <div class="input-group"> <!-- Agregamos un div para el grupo de entrada -->
                            <input type="text"  hidden name="id_contacto" id="id_contacto">
                            <input type="text" class="form-control" value="" id="seleccionarcontactos">

                        </div>
                        <div class="col-2 form-group" id="">
                            <table class="table table-hover">
                                <tbody id="table_contacto"></tbody>
                            </table>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md m-2">
                            <label for="">Razón social/Nombre contacto</label>
                            <input onkeydown="cambioDeInput(event,'contacto_rut')" type="text" name="contacto_razon_social" class="form-control" value=""
                                 id="contacto_razon_social">
                                <label id="l_contacto_razon_social" style="display: none; color: red" for="">Campo obligatorio</label>
                        </div>
                        <div class="col-md m-2">
                            <label for="">Rut</label>
                            <input onkeydown="cambioDeInput(event,'contacto_giro')"  type="text" class="form-control" value=""  name="contacto_rut"
                                id="contacto_rut">
                            <span id="rut_span" style="display: none"><label for=""
                                    id="error_rut"></label></span>
                                    <label id="l_contacto_rut" style="display: none; color: red" for="">Campo obligatorio</label>

                        </div>
                        <div class="col-md m-2">
                            <label for="">giro</label>
                            <input onkeydown="cambioDeInput(event,'contacto_telefono')"  type="text" name="contacto_giro" class="form-control" value="" 
                                id="contacto_giro">
                                <label id="l_contacto_giro" style="display: none; color: red" for="">Campo obligatorio</label>

                        </div>
                        <div class="col-md m-2">
                            <label   for="">Telefono</label>
                            <input onkeydown="cambioDeInput(event,'contacto_correo')" type="text" name="contacto_telefono" class="form-control" value="" 
                                id="contacto_telefono">
                                <label id="l_contacto_telefono" style="display: none; color: red" for="">Campo obligatorio</label>


                        </div>


                        <div class="row">
                        </div>
                        <div class="col-md m-2">
                            <label for="">Correo</label>
                            <input onkeydown="cambioDeInput(event,'contacto_direccion')"  type="text" class="form-control" value="" name="contacto_correo"
                                id="contacto_correo">
                                <label id="l_contacto_correo" style="display: ; color: red" for="">Campo obligatorio</label>

                        </div>
                        <div class="col-md m-2">
                            <label for="">Direccion</label>
                            <input onkeydown="cambioDeInput(event,'region')" type="text" class="form-control" value=""  name="contacto_direccion"
                                id="contacto_direccion">
                                <label id="l_contacto_direccion" style="display: none; color: red" for="">Campo obligatorio</label>

                        </div>
                        <div class="col-md m-2">
                            <label for="">Region</label>
                            <select  class="form-control mayuscula" name="region" id="region">
                                <option value="">Seleccionar</option>
                                @foreach ($regiones as $region)
                                    @if (!empty($idregion))
                                        @if ($region->id == $idregion)
                                            <option selected value="{{ $region->id }}"
                                                {{ old('region') == $region->id ? 'selected' : '' }}>
                                                {{ $region->des_region }}</option>
                                        @else
                                            <option value="{{ $region->id }}"
                                                {{ old('region') == $region->id ? 'selected' : '' }}>
                                                {{ $region->des_region }}</option>
                                        @endif
                                    @else
                                        <option value="{{ $region->id }}"
                                            {{ old('region') == $region->id ? 'selected' : '' }}>{{ $region->des_region }}
                                        </option>
                                    @endif
                                @endforeach
                            </select>
                            <label id="l_region" style="display: none; color: red" for="">Campo obligatorio</label>

                        </div>
                        <div class="col-md m-2">
                            <label for="">Comuna</label>
                            <select  class="form-control  mayuscula"  name="comuna" id="comuna">
                                <option value="">Seleccionar</option>

                                @if (!empty($comunasporregion))
                                    @foreach ($comunasporregion as $data)
                                        @if (!empty($idcomuna))
                                            @if ($data->id == $idcomuna)
                                                <option selected value="{{ $data->id }}"
                                                    {{ old('comuna') == $data->id ? 'selected' : '' }}>
                                                    {{ $data->des_comuna }}</option>
                                            @else
                                                <option value="{{ $data->id }}"
                                                    {{ old('comuna') == $data->id ? 'selected' : '' }}>
                                                    {{ $data->des_comuna }}</option>
                                            @endif
                                        @else
                                            <option value="{{ $data->id }}"
                                                {{ old('comuna') == $data->id ? 'selected' : '' }}>{{ $data->des_comuna }}
                                            </option>
                                        @endif
                                    @endforeach
                                @endif

                            </select>
                        <label id="l_comuna" style="display: none; color: red" for="">Campo obligatorio</label>

                        </div>


                    </div>
                    {{-- <div class="row">
                        <div class="col-md m-2">
                            <label for="">observacion</label>
                          <textarea name="observacion" class="form-control" id="" required name="contacto_observacion"  cols="30" rows="10"></textarea>
                            
                        </div>
                    </div> --}}

                        <div>

                            <label for="">Crear Presupuesto</label><br>
                            <input type="checkbox" name="crear_presupuesto" id="">
                            
                        </div>
                    <div style="text-align: right">
                        <input type="button" value="Atras" onclick="atras(2)" class="m-2">

                        <input type="submit" value="Siguiente" class="m-2" id="botonSiguiente">
                    </div>

                </div> {{-- fin del card  session 23 --}}

            </div>

        </form>
        {{-- fin del container --}}
    </div>


    {{-- //modals --}}

        <!-- Modal Servicios -->
        <div class="modal" id="modalSelectServicios">
            <div class="modal-dialog">
                <div class="modal-content">
    
                    <!-- Modal Header -->
                    <div class="modal-header">
                        <h4 class="modal-title">Servicio</h4>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
    
                    <!-- Modal body -->
                    <div class="modal-body">
                        <div class="col-12 form-group">
                            {{-- <input type="" value="" class="form-control mayuscula" id="nombre_servicio"
                                placeholder="Servicio" name="" value=""> --}}
                                <input type="text" id="searchInput" class="form-control mayuscula"  placeholder="Buscar...">

                                <span id="faltaServicio"  style="display: none"><label for="" style="color: red">Debe seleccionar almenos un servicio</label></span>
                        </div>
                        <div class="table-scroll table-responsive">
                            <table class="table table-hover">
                                <tbody id="tableservicios">
                                    {{-- {{$servicios}} --}}
                                    @foreach ($servicios as $los_datos)
                                        <tr>
                                            <td class="td-val" onclick="agregarBuscador({{$los_datos->sku}})">{{$los_datos->sku}} || {{$los_datos->nombre_servicio}}</td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>

    <!-- Modal Descuento -->
    <div class="modal" id="modalDescuento">
        <div class="modal-dialog">
            <div class="modal-content">

                <!-- Modal Header -->
                <div class="modal-header">
                    <h4 class="modal-title">Descuento Porcentaje</h4>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>

                <!-- Modal body -->
                <div class="modal-body">
                    <div class="m-2">
                        <input type="number" class="form-control"  onkeydown="funcionPorcentajeAplicado(event)" value="" id="porcentajeAplicado">

                    </div>
                    <div class="m-2" style="text-align: right">
                        <button type="button" class="btn btn-success" data-bs-dismiss="modal"
                            onclick="aplicarDescuento();">Aplicar</button>

                    </div>
                </div>
            </div>
        </div>
    </div>

<!-- Modal Descuento -->
<div class="modal" id="modalDescuentoTotal">
    <div class="modal-dialog">
        <div class="modal-content">

            <!-- Modal Header -->
            <div class="modal-header">
                <h4 class="modal-title">Descuento</h4>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>

            <!-- Modal body -->
            <div class="modal-body">
                <div class="m-2">
                    <input type="number" class="form-control" value=""  onkeydown="funcionPorcentajeAplicadoPesos(event)" id="dscuentoTotalAplicadoT">

                </div>
                <div class="m-2" style="text-align: right">
                    <button type="button" class="btn btn-success" data-bs-dismiss="modal"
                        onclick="aplicarDescuentoTotal();">Aplicar</button>

                </div>
            </div>
        </div>
    </div>
</div>
    

    {{-- MODAL ABONO --}}
    <div class="modal" id="modalAbono">
        <div class="modal-dialog">
            <div class="modal-content">

                <!-- Modal Header -->
                <div class="modal-header">
                    <h4 class="modal-title">Abono</h4>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>

                <!-- Modal body -->
                <div class="modal-body">
                    <div class="m-2">
                        <label for="">Total</label>

                        <input type="number" class="form-control" value="" id="abono">

                    </div>
                    <div class="m-2">
                        <label for="">Medio de pago</label>
                        <select name="" class="form-control text-uppercase" id="mediosPagosSelect">
                            <option class="" value="">Seleccionar</option>
                            @if (!empty($medios_pagos))
                                @foreach ($medios_pagos as $data)
                                    <option value="{{ $data->id }}"
                                        {{ old('modopago') == $data->id ? 'selected' : '' }}>{{ $data->descripcion }}
                                        {{ $data->apellido }}</option>
                                @endforeach
                            @endif
                        </select>

                    </div>
                    <div class="m-2" style="text-align: right">
                        <button type="button" class="btn btn-success" data-bs-dismiss="modal"
                            onclick="aplicarAbono();">Aplicar</button>

                    </div>
                </div>



            </div>
        </div>
    </div>

    <script>
        //VARIABLES GLOBALES
        //VARIABLES GLOBALES
        var resultadoServicios = "";
        var resultadoServiciosSeleccionados = [];
        var resultadoRepuestos = "";
        var resultadoRepuestosSeleccionados = [];
        var totalNetoCompra = 0;
        var TotalCompra = 0;
        var TotalPorcentajeCompra = 0;
        var TotalPorcentajeDescuento = 0;
        var totalAbono = 0;
        var metodoDePago = "";
        var arrayequipos = [];
        var arrayContacto = [];
        var dscuentoTotalAplicadoT = 0;
        var idServicioGlobal = "";
        var skuServicioGlobal = "";
        var isActiveDescuentoEntero = false;



        

        var repuestos_medidas = @json($repuestos_medidas);



        
        function actualizarTable(id){
            var isChecked = $('#check_' + id).prop('checked');
                if (isChecked) {

                     if(id == 20) //id del repuesto OTRO
                     {
                        $('#check_' + id).prop('checked', false); // Desmarca el checkbox

                     }
                    // console.log('El checkbox está marcado');
                    agregarRepuesto(id);

                    // Realiza las acciones que necesites si el checkbox está marcado
                } else {
                    // console.log('El checkbox no está marcado');
                    // agregarRepuesto(id);
                    eliminarFilaRepuesto(id);
                    // Realiza las acciones que necesites si el checkbox no está marcado
                }
        }


            function limpiar(){

                $("#campoServicio").val("");
            $("#nombredelservicio").val("");
            $("#campoServicioDescripcion").val("");
            $("#campoServicioCantidad").val("");

            }

        function buscarServicioFunction(event,sku = ""){ 




            if (event.key === 'Enter') {
                getId = $("#campoServicio").val();

                if(getId == ""){
                    limpiar();
                }

                var data = @json($servicios);
                    //eliminar espacios
                    getId=   getId.replace(/\s/g, '');
                    var servicioSele=  data.find(servicio => servicio.sku === getId);
                    
                    
                    
                    if (servicioSele) {
                    console.log("El servicio existe:", servicioSele);
                    $("#nombredelservicio").val(servicioSele.nombre_servicio);
                    $("#campoServicioDescripcion").focus();

                     idServicioGlobal = servicioSele.id;
                     skuServicioGlobal = servicioSele.sku;
                    



                } else {
                    $("#campoServicio").focus();
                    // console.log("No se encontró ningún servicio con el SKU:", getId);
                    alert("SKU no encontrado")
                }
                    console.log(servicioSele);
                // console.log(data);
                // // const buscarServicio = data.findIndex(objeto => objeto.id === getId);
                // const buscarServicio = data.find(objeto => objeto.id === getId);

                // console.log(buscarServicio);
                    //  $("#campoServicioDescripcion").focus();

             }
        }
        function cambioDeInputOnchange(event,opcion){


        $("#"+opcion).focus();

        // alert(opcion);


        }

        function cambioDeInput(event,opcion){



            if (event.key === 'Enter') {

            $("#"+opcion).focus();

// alert(opcion);
            

            }
        }

        function funcionPorcentajeAplicadoPesos(event){

                if (event.key === 'Enter') {

                $("#modalDescuentoTotal").modal("hide");

                aplicarDescuentoTotal();

                }
            }
        
        function funcionPorcentajeAplicado(event){

                if (event.key === 'Enter') {

            $("#modalDescuento").modal("hide");

                    aplicarDescuento();

                }
        }

        function buscarServicioFunctionDesc(event){

            if (event.key === 'Enter') {

            $("#campoServicioCantidad").focus();

            }
        }
        function buscarServicioFunctionCan(event){

            if (event.key === 'Enter') {

                //  var campoServicioSku = $("#campoServicio").val();
                 var campoServicioDescripcion = $("#campoServicioDescripcion").val();
                 var campoServicioCantidad = $("#campoServicioCantidad").val();

                 agregar2(idServicioGlobal,skuServicioGlobal,campoServicioDescripcion,campoServicioCantidad)
            $("#campoServicio").focus();

            }
            }
        
        
        //validar rut
        function validar_rut_contacto(rut) {
            $.ajax({
                headers: {
                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                },
                type: 'GET',
                url: "{{ route('validarrut.contacto') }}",
                data: {
                    'rut': rut
                },
                success: function(data) {
                    //1 rut existe
                    console.log(data);
                    if (data == 1) {
                        $("#contacto_rut").val('');
                        $("#rut_span").css("display", "")
                        $("#error_rut").text("Rut registrado");
                    } else {
                        $("#rut_span").css("display", "none")
                    }
                },
                error: function(xhr, status) {
                    alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
                }
            });
        }


        $(document).ready(function() {

                //  $('#fecha_entrega').datepicker();


            //buscador de los servicios modal

            $("#searchInput").on("input", function () {
            var value = $(this).val().toUpperCase();
            $("#tableservicios tr").filter(function () {
                $(this).toggle($(this).text().toUpperCase().indexOf(value) > -1);
            });
        });

            //validar que si queda vacio, se elminen todos los datos
            $('#campoServicio').on('keyup', function() {

                getId = $("#campoServicio").val();

                    if(getId == ""){
                        limpiar();
                    }
            });


            // <select  class="form-control mayuscula" name="sucursal" id="sucursal">
            $("#sucursal").change(function() {
                //   buscar_comuna($("#sucursal option:selected").val(),"#sucursal");
                $.ajax({

                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    },
                    type: 'POST',
                    url: "{{ route('getoperarios') }}",
                    data: {
                        'idsucursal': $("#sucursal option:selected").val(),





                    },
                    success: function(data) {
                        console.log("datammmmmm");

                        console.log(data);

                        $('#operario').empty();
                        $('#equipo_chofer').empty();

                        option = "";
                        option2 = "";
                        var radioButtons = '<div class="d-flex">';


                            $.each(data.operarios, function(index, objeto) {
                                radioButtons += '<div class="form-check me-3">';

                                    if(index == 0){
                                            radioButtons += '<input checked class="form-check-input" type="radio" name="operario" id="operario' + objeto.id_user + '" value="' + objeto.id_user + '">';
                                    }else{
                                        radioButtons += '<input  class="form-check-input" type="radio" name="operario" id="operario' + objeto.id_user + '" value="' + objeto.id_user + '">';

                                    }



                                radioButtons += '<label class="form-check-label" for="operario' + objeto.id_user + '">';
                                radioButtons += objeto.nombre + ' ' + objeto.apellido;
                                radioButtons += '</label>';
                                radioButtons += '</div>';
                            });

radioButtons += '</div>';
$('#operario').html(radioButtons);

                        // $.each(data.operarios, function(index, objeto) {
                        //     option += "<option value=" + objeto.id_user + ">" + objeto
                        //         .nombre +"  "+ objeto
                        //         .apellido+ "</option>"
                        // });

                        option2 += "<option value=''>Seleccionar</option>"
                        $.each(data.choferes, function(index, objeto) {
                            option2 += "<option value=" + objeto.id_user + ">" + objeto
                                .nombre +"  "+ objeto
                                .apellido+ "</option>"
                        });


                        $('#equipo_chofer').append(option2);
                        $('#operario').append(option);

                    },
                    error: function(xhr, status) {
                        alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
                    }
                });
            });

            //traemos las comunas de la region seleccionada
            $("#region").change(function() {
                buscar_comuna($("#region option:selected").val(), "#comuna");
            });
            $("#mediosPagosSelect").change(function() {
                // Obtener el valor seleccionado
                metodoDePago = $(this).val();

                // Realizar alguna acción con el valor seleccionado
                // console.log("Valor seleccionado: " + selectedValue);
                // Puedes hacer lo que necesites con el valor seleccionado aquí
            });

            //Validar rut
            $("#contacto_rut").change(function() {
                //esta funcion (checkRut) se encuentra en funciones.js
                var resultado = checkRut($("#contacto_rut").val());
                if (resultado == "Rut incorrecto") {
                    $("#contacto_rut").val('');
                    $("#rut_span").css("display", "")
                    $("#error_rut").text("Rut incorrecto");

                } else {
                    $("#rut_span").css("display", "none")
                    validar_rut_contacto($("#contacto_rut").val());
                }
            });

            $('#contacto_rut').on('input', function() {
                $("#contacto_rut").val(add_guion_rut($("#contacto_rut").val()));
            });

            // alert("j");


                /////////////////////////////////////
                /////////////////////////////////////

                //PARA CARGAR ALGUNOS SERIVICIOS AL INICIAR
                // var data = @json($servicios);
                // var valorIngresado = "a";

                // resultadoServicios = $.grep(data, function(servicio) {
                //     // Comparar el nombre y el SKU en minúsculas para que la búsqueda sea insensible a mayúsculas/minúsculas
                //     var nombreLowerCase = servicio.nombre_servicio.toLowerCase();
                //     var skuLowerCase = servicio.sku.toLowerCase();
                //     var letraBusqueda = valorIngresado.toLowerCase();

                //     return nombreLowerCase.includes(letraBusqueda) || skuLowerCase.includes(
                //         letraBusqueda);
                // });
                // resultadoServicios = resultadoServicios.slice(0, 10);


                // $(resultadoServicios).each(function(i, v) {
                //         $('#tableservicios').append(
                //             '<tr><td class="agregar" onclick="agregarBuscador(' + v.sku + ')">' + v
                //             .sku + " ||  " + v
                //             .nombre_servicio.toUpperCase() + '</td></tr');
                //     })
                /////////////////////////////////////
                /////////////////////////////////////



            // Agrega un manejador de eventos para el evento keyup
            $('#nombre_servicio').on('keyup', function() {
                // Obtiene el valor del campo de entrada
                var valorIngresado = $(this).val();

                var data = @json($servicios);


                // Obtener el texto de búsqueda por teclado
                // var valorIngresado = prompt("Ingrese una letra para buscar servicios:");

                // Filtrar los elementos por nombre o SKU que contengan la letra ingresada
                resultadoServicios = $.grep(data, function(servicio) {
                    // Comparar el nombre y el SKU en minúsculas para que la búsqueda sea insensible a mayúsculas/minúsculas
                    var nombreLowerCase = servicio.nombre_servicio.toLowerCase();
                    var skuLowerCase = servicio.sku.toLowerCase();
                    var letraBusqueda = valorIngresado.toLowerCase();

                    return nombreLowerCase.includes(letraBusqueda) || skuLowerCase.includes(
                        letraBusqueda);
                });
                resultadoServicios = resultadoServicios.slice(0, 10);

                // $('#tableservicios').empty();

                if (valorIngresado != "") {

                    $(resultadoServicios).each(function(i, v) {
                        $('#tableservicios').append(
                            '<tr><td class="agregar" onclick="agregarBuscador(' + v.sku + ')">' + v
                            .sku + " ||  " + v
                            .nombre_servicio.toUpperCase() + '</td></tr');
                    })
                } else {
                    // $('#tableservicios').empty();

                }
                // console.log(resultadoServicios);


            });

            // Agrega un manejador de eventos para el evento keyup
            $('#nombre_repuesto').on('keyup', function() {
                // Obtiene el valor del campo de entrada
                var valorIngresado = $(this).val();

                var data = @json($repuestos);


                console.log("repsuestos repuestos");
                console.log(data);

                // Obtener el texto de búsqueda por teclado
                // var valorIngresado = prompt("Ingrese una letra para buscar servicios:");

                // Filtrar los elementos por nombre o SKU que contengan la letra ingresada
                resultadoRepuestos = $.grep(data, function(servicio) {
                    // Comparar el nombre y el SKU en minúsculas para que la búsqueda sea insensible a mayúsculas/minúsculas
                    var nombreLowerCase = (servicio.nombre || '').toLowerCase();
                    var skuLowerCase = (servicio.categoria || '').toLowerCase();
                    var letraBusqueda = valorIngresado.toLowerCase();

                    return nombreLowerCase.includes(letraBusqueda) || skuLowerCase.includes(
                        letraBusqueda);
                });


                $('#tablerepuestos').empty();

                if (valorIngresado != "") {

                    $(resultadoRepuestos).each(function(i, v) {
                        $('#tablerepuestos').append(
                            '<tr><td class="agregar" onclick="agregarRepuesto(' + v.id + ')">' +
                            v
                            .nombre.toUpperCase() + '</td></tr');
                    })
                } else {
                    $('#tablerepuestos').empty();

                }
                // console.log(resultadoServicios);


            });

            // Agregar un controlador de eventos para cambiar el estado de la casilla de verificación
            $("#movil").click(function() {


                var estaMarcado = $("#movil").prop("checked");

                if (estaMarcado) {
                    $("#equipo_chofer").css("display", "");
                } else {
                    $("#equipo_chofer").css("display", "none");
                }

            });

            // Agrega un manejador de eventos para el evento keyup
            $('#equipo').on('keyup', function() {
                // Obtiene el valor del campo de entrada
                var valorIngresado = $(this).val();

                var data = @json($equipos);

                arrayequipos = @json($equipos);
                // console.log(data);

                // Obtener el texto de búsqueda por teclado
                // var valorIngresado = prompt("Ingrese una letra para buscar servicios:");

                // Filtrar los elementos por nombre o SKU que contengan la letra ingresada
                var resultadoRepuestos = $.grep(data, function(equipo) {
                    // Comparar el nombre y el SKU en minúsculas para que la búsqueda sea insensible a mayúsculas/minúsculas
                    var serieLowerCase = (equipo.serie || '')
                .toLowerCase(); // Si serie es null, se establece como cadena vacía
                    var patenteLowerCase = (equipo.patente || '')
                .toLowerCase(); // Si patente es null, se establece como cadena vacía
                    var nomBusqueda = valorIngresado.toLowerCase();

                    return serieLowerCase.includes(nomBusqueda) || patenteLowerCase.includes(
                        nomBusqueda);
                });

                console.log(resultadoRepuestos);

                $('#tableequipo').empty();

                if (valorIngresado != "") {



                    $(resultadoRepuestos).each(function(i, v) {
                        var patente = v.patente ? v.patente : "";
                        var serie = v.serie ? v.serie : "";
                        $('#tableequipo').append(
                            '<tr><td class="agregar" onclick="selecionarEquipo(' + v.id +
                            ')">' +
                            patente + " (" + serie + ")" + '</td></tr');
                    })
                } else {
                    $('#tableequipo').empty();

                }



            });


            // CLIENTE

            // Agrega un manejador de eventos para el evento keyup
            $('#seleccionarcontactos').on('keyup', function() {
                // Obtiene el valor del campo de entrada
                var valorIngresado = $(this).val();

                var data = @json($contactos);

                arrayContacto = @json($contactos);
                console.log(data);

                // Obtener el texto de búsqueda por teclado
                // var valorIngresado = prompt("Ingrese una letra para buscar servicios:");

                //  Filtrar los elementos por nombre o SKU que contengan la letra ingresada
                var resultadoRepuestos = $.grep(data, function(datos) {
                    var razon_socialLowerCase = (datos.razon_social || '').toLowerCase();
                    var rutLowerCase = (datos.rut || '').toLowerCase();
                    var nomBusqueda = valorIngresado.toLowerCase();

                    return razon_socialLowerCase.includes(nomBusqueda) || rutLowerCase.includes(
                        nomBusqueda);
                }).slice(0, 10);

                console.log(resultadoRepuestos);

                $('#table_contacto').empty();

                if (valorIngresado != "") {

                    $(resultadoRepuestos).each(function(i, v) {
                        $('#table_contacto').append(
                            '<tr><td class="agregar" onclick="seleccionarContacto(' + v.id +
                            ')">' +
                            v.razon_social + "(- " + v.rut + ")" + '</td></tr');
                    })
                } else {
                    $('#table_contacto').empty();

                }



            });
            //seleccionar los contactos

        });
        //buscar comuna
        function buscar_comuna(id_region, id_comunas, direccion = "") {
            $.ajax({
                headers: {
                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                },
                type: 'GET',
                url: "{{ route('buscar_comunas') }}",
                data: {
                    'id_region': id_region
                },
                success: function(data) {

                    $(id_comunas).empty();

                    $(id_comunas).append('<option value="">' +
                            "Seleccionar" + '</option>');
                    $.each(data, function(id, comuna_nombre_array) {
                        $(id_comunas).append('<option value=' + comuna_nombre_array.id + '>' +
                            comuna_nombre_array.des_comuna + '</option>');
                    });
                },
                error: function(xhr, status) {
                    alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
                }
            });

        }

        function seleccionarContacto(data) {
            console.log(data);
            $('#table_contacto').empty();

            $.each(arrayContacto, function(index, objeto) {
                if (objeto.id === data) {
                    $("#contacto_nombre").val(objeto.nombre);
                    $("#contacto_rut").val(objeto.rut);
                    $("#id_contacto").val(objeto.id);


                    $("#contacto_razon_social").val(objeto.razon_social);
                    $("#contacto_correo").val(objeto.correo.trim());
                    $("#contacto_telefono").val(objeto.telefono);
                    $("#contacto_giro").val(objeto.giro);



                    $("#contacto_direccion").val(objeto.nombre_direccion);
                    $("#region").val(objeto.idregion);

                    $("#comuna").val(objeto.comunas_id);

                    $("#l_contacto_razon_social").css("display","none");
                    $("#l_contacto_rut").css("display","none");
                    $("#l_contacto_giro").css("display","none");
                    $("#l_contacto_telefono").css("display","none");
                    $("#l_contacto_correo").css("display","none");
                    $("#l_contacto_direccion").css("display","none");
                    $("#l_region").css("display","none");
                    $("#l_comuna").css("display","none");

                    // $("#equipo_patente").val(objeto.patente);
                    // $("#equipo_marca").val(objeto.marca);
                    // $("#equipo_motor").val(objeto.motor);
                    // $("#equipo_ano").val(objeto.ano);
                    // $("#equipo_serie").val(objeto.serie);
                    // $("#equipo_combustible").val(objeto.combustible_id);





                }
                // else{
                //     $("#l_contacto_razon_social").css("display","");
                //     $("#l_contacto_rut").css("display","");
                //     $("#l_contacto_giro").css("display","");
                //     $("#l_contacto_telefono").css("display","");
                //     $("#l_contacto_correo").css("display","");
                //     $("#l_contacto_direccion").css("display","");
                //     $("#l_region").css("display","");
                //     $("#l_comuna").css("display","");
                // }

            });

        }


        function eliminarFilaRepuesto(dataId) {
            const buscarRepuesto = resultadoRepuestosSeleccionados.findIndex(objeto => objeto.id === dataId);

            if (buscarRepuesto !== -1) {
                // Si el objeto con "id" 5 existe, eliminarlo
                resultadoRepuestosSeleccionados.splice(buscarRepuesto, 1);
                calcularTotalTableRepuestos();
            }
        }

        function eliminarFilaServicio(dataId) {
            const buscarServicio = resultadoServiciosSeleccionados.findIndex(objeto => objeto.id === dataId);

            if (buscarServicio !== -1) {
                // Si el objeto con "id" 5 existe, eliminarlo
                resultadoServiciosSeleccionados.splice(buscarServicio, 1);
                calcularTotalTable();
            }
        }


        function agregarRepuesto(data) {
// alert(data);
            $('#tablerepuestos').empty();
            $('#nombre_repuesto').val("");
            const min = 10000;
            const max = 20000;
            const allRepuestos =   @json($repuestos);


            const randomNumber = Math.floor(Math.random() * (max - min + 1)) + min;



            // console.log(resultadoServicios);
            // const repuestoSeleccionado = resultadoRepuestos.find(objeto => objeto.id === data);
            const repuestoSeleccionado = allRepuestos.find(objeto => objeto.id === data);

            if(repuestoSeleccionado.nombre == "OTRO"){
                repuestoSeleccionado.id = repuestoSeleccionado.id+randomNumber;
            }
                repuestoSeleccionado.cantidad = 1;
            repuestoSeleccionado.descripcionOtro = ""; 
            repuestoSeleccionado.medidaOtro = ""; 
            
        

            
            // servicioSeleccionado.total= servicioSeleccionado.precio_neto * 1;
            //guardamos en un array

            console.log("aaaaa Revisar::");
            console.log(repuestoSeleccionado.id);

            const buscarRepuesto = resultadoRepuestosSeleccionados.find(objeto => objeto.id === repuestoSeleccionado.id);

            if (buscarRepuesto) {

                buscarRepuesto.cantidad = buscarRepuesto.cantidad + 1;

            } else {
                resultadoRepuestosSeleccionados.push(repuestoSeleccionado);



            }

            calcularTotalTableRepuestos();
            // $('#tabla_servicios_selecionados').append('<tr><td>' + servicioSeleccionado.nombre_servicio + '</td></tr>');

            //console.log(repuestoSeleccionado);
        }
        
        function agregarBuscador(sku) {
        
            // $("#modalSelectServicios").hide();
            $("#modalSelectServicios").modal("hide");
            $("#campoServicio").val(sku);
             $("#campoServicio").focus();
            

        }

        function agregar2(idSer,skuSer,desSer,canSer) {

            
            // $('#tableservicios').empty();
            $('#nombre_servicio').val("");




            // console.log(resultadoServicios);
            var data = @json($servicios);
            //eliminar espacios

            // const servicioSeleccionado = resultadoServicios.find(objeto => objeto.id === idSer);
            const servicioSeleccionado = data.find(objeto => objeto.id === idSer);

            if(canSer  == "" || canSer <= 0){
                canSer = 1;
            }

            servicioSeleccionado.cantidad = canSer;
            servicioSeleccionado.descripcion = desSer;

            // servicioSeleccionado.total= servicioSeleccionado.precio_neto * 1;
            //guardamos en un array

            const buscarServicio = resultadoServiciosSeleccionados.find(objeto => objeto.id === servicioSeleccionado.id);

            if (buscarServicio) {

                buscarServicio.cantidad = parseFloat(buscarServicio.cantidad) + parseFloat(1);
            } else {
                resultadoServiciosSeleccionados.push(servicioSeleccionado);

            }
            // resultadoServiciosSeleccionados.push(servicioSeleccionado);

            calcularTotalTable();
            // $('#tabla_servicios_selecionados').append('<tr><td>' + servicioSeleccionado.nombre_servicio + '</td></tr>');

            console.log(servicioSeleccionado);
        }
        function agregarDescripcion(id, inputElement) {
            var nuevoValor = inputElement.value;
            $.each(resultadoServiciosSeleccionados, function(index, objeto) {
                if (objeto.id === id) {
                    objeto.descripcion = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });

            calcularTotalTable();
        }


        
        function agregarMedidaOtro(id, inputElement){


            var nuevoValor = inputElement.value;

            $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
                if (objeto.id === id) {
                    objeto.medidaOtro = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });
            console.log(resultadoRepuestosSeleccionados);
            calcularTotalTableRepuestos();

        }

        function agregarDescripcioncOtro(id, inputElement){


            var nuevoValor = inputElement.value;
            console.log(id+"____"+nuevoValor);

            $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
                if (objeto.id === id) {
                    objeto.descripcionOtro = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });
            calcularTotalTableRepuestos();

            console.log(resultadoRepuestosSeleccionados);
        }

        function cambiodevalormanualrepuestos(id, inputElement) {
    var nuevoValor = inputElement.value;
    // Verificar si el nuevo valor está vacío y establecerlo en "1" si es así
    if (nuevoValor.trim() === "" || parseFloat(nuevoValor) === 0) {
        nuevoValor = "1";
         // Establecer el valor del campo en "1" después de realizar la asignación
    inputElement.value = "1";
    }
    $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
        if (objeto.id === id) {
            objeto.cantidad = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
        }
    });

    calcularTotalTableRepuestos();

   
}
        // function cambiodevalormanualrepuestos(id, inputElement) {
        //     var nuevoValor = inputElement.value;
        //     $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
        //         if (objeto.id === id) {
        //             objeto.cantidad = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
        //         }
        //     });

        //     calcularTotalTableRepuestos();
        // }


        function cambiodevalormaPrecio(id, inputElement) {
            
            var nuevoValor = inputElement.value;
            $.each(resultadoServiciosSeleccionados, function(index, objeto) {
                if (objeto.id === id) {
                    objeto.precio_neto = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });

            calcularTotalTable();
        }

        

        function sumar_repuesto(data) {
            $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
                if (objeto.id === data) {
                    objeto.cantidad = parseInt(objeto.cantidad) +
                    1; // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });


            calcularTotalTableRepuestos();
        }

        function restar_repuesto(data) {
            $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
                if (objeto.id === data) {

                    if (objeto.cantidad > 1) {
                        objeto.cantidad = objeto.cantidad - 1;
                    }
                    // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });
            calcularTotalTableRepuestos();

        }

        //servicios
        function sumar(data) {
            $.each(resultadoServiciosSeleccionados, function(index, objeto) {
                if (objeto.id === data) {
                    objeto.cantidad = parseInt(objeto.cantidad) +
                    1; // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });


            calcularTotalTable();
        }

        function restar(data) {
            $.each(resultadoServiciosSeleccionados, function(index, objeto) {
                if (objeto.id === data) {

                    if (objeto.cantidad > 1) {
                        objeto.cantidad = objeto.cantidad - 1;
                    }
                    // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });
            calcularTotalTable();

        }

        function calcularTotalTableRepuestos() {


            console.log(repuestos_medidas);
            $('#tabla_repuesto_selecionados').empty();

            console.log("resultadoRepuestosSeleccionados");
            console.log(resultadoRepuestosSeleccionados);

                // Filtrar las opciones basadas en el valor de id_repuestos
               

            $.each(resultadoRepuestosSeleccionados, function(index, objeto) {


                // var opcionesArray = ["Opción 1", "Opción 2", "Opción 3"];
                var opcionesArray = repuestos_medidas.filter(function(opcion) {
                    return opcion.id_repuestos === objeto.id; // Puedes cambiar este valor según tus necesidades
                });


                var tr = "<tr>";

                    if(objeto.nombre != "OTRO"){
                        tr += "<td>" + (objeto.nombre || '').toUpperCase() + "</td>";

                    }else{
                        
                      //  tr += "<td>" + "<input type='text' onchange='agregarDescripcioncOtro("+objeto.id+",this)'  id=descrip_repuesto"+objeto.id+"  value="+objeto.descripcionOtro+">" + "</td>";
                      tr += "<td>" + "<input type='text' onchange='agregarDescripcioncOtro("+objeto.id+",this)' id='descrip_repuesto"+objeto.id+"' value='"+objeto.descripcionOtro+"'>" + "</td>";

                    }
                // tr += "<td>" + (objeto.nombre || '').toUpperCase() + "</td>";
                if(objeto.nombre != "OTRO"){
 
                    tr += "<td><select id='miSelect"+objeto.id+"' onchange='handleSelectChange(" + objeto.id +")' >";

                        for (var i = 0; i < opcionesArray.length; i++) {

                            if ('valor' in objeto) {
                                // alert("jj");

                                if(objeto.valor == opcionesArray[i]["id"] ){
                                    tr += "<option selected  value='" + opcionesArray[i]["id"] + "'>" + opcionesArray[i]["medida"] + "</option>";

                                }else{
                                    tr += "<option value='" + opcionesArray[i]["id"] + "'>" + opcionesArray[i]["medida"] + "</option>";

                                }

                            }else{

                                tr += "<option value='" + opcionesArray[i]["id"] + "'>" + opcionesArray[i]["medida"] + "</option>";

                                if(i == 0){
                                    objeto.valor = opcionesArray[i]["id"];
                                }
                            }                    
                        }

                        tr += "</select>"+ "</td>";


                    }else{
                        
                        tr += "<td>" + "<input type='text' onchange='agregarMedidaOtro("+objeto.id+",this)'  id=medida_repuesto"+objeto.id+"  value="+objeto.medidaOtro+">" + "</td>";
                        
                    }


                tr += "<td>" + (objeto.categoria || '').toUpperCase() + "</td>";
                tr += "<td>" + "<input type='button' value='-'  onclick='restar_repuesto(" + objeto.id + ")' >" +
                    "<input  type='text' onchange='cambiodevalormanualrepuestos(" + objeto.id +
                    ",this)' onkeypress='soloNumeros(event)' class='narrow-input' value='" + objeto.cantidad +
                    "' id='valores_repuestos" + objeto
                    .id + "'>" + "<input type='button' onclick='sumar_repuesto(" + objeto.id + ")'  value='+'>" +
                    "</td>";

                tr += "<td>" + '<a  onclick="eliminarFilaRepuesto(' + objeto.id + ')"  >' + "Eliminar" + "</a>" +
                    "</td>";
                tr += "</tr>";

                $('#tabla_repuesto_selecionados').append(tr);

            });
            $('#arrayDatosTablaRepuestos').val(JSON.stringify(resultadoRepuestosSeleccionados));



        }

        function handleSelectChange(id){
                idSelect = "#miSelect"+id;
               var  valorSele = $(idSelect).val();
                $.each(resultadoRepuestosSeleccionados, function(index, objeto) {
                if (objeto.id === id) {
                    
                    objeto.valor =  valorSele; // Puedes establecer cualquier valor inicial para "cantidad"
                    // calcularTotalTableRepuestos();
            $('#arrayDatosTablaRepuestos').val(JSON.stringify(resultadoRepuestosSeleccionados));

                }
            });

            }

        //CALCULOS
        function cambiodevalormanual(id, inputElement) {
            var nuevoValor = inputElement.value;

            console.log(id);
            console.log(nuevoValor);

            $.each(resultadoServiciosSeleccionados, function(index, objeto) {
                if (objeto.id === id) {
                    objeto.cantidad = nuevoValor; // Puedes establecer cualquier valor inicial para "cantidad"
                }
            });

            calcularTotalTable();
        }

        function aplicarAbono() {

            totalAbono = $("#abono").val();
            // $("#l_descuento").text(descuentoPorcentaje+"%");
            calcularTotalTable();

        }
        function aplicarDescuentoTotal() {

            dscuentoTotalAplicadoT = $("#dscuentoTotalAplicadoT").val();
            isActiveDescuentoEntero = true;
// $("#l_descuento").text(descuentoPorcentaje+"%");
calcularTotalTable(1);
}
        function aplicarDescuento() {

            TotalPorcentajeDescuento = $("#porcentajeAplicado").val();
            // $("#l_descuento").text(descuentoPorcentaje+"%");
            calcularTotalTable();
            isActiveDescuentoEntero = false;

        }

        function calcularTotalTable(activardescuento = 0) {
            // alert("x");
            $('#tabla_servicios_selecionados').empty();
            
         var tipoUsuario = @json(\App\Models\User::tipoUsuario());
        
            //limpiamos los campos
            $("#campoServicio").val("");
            $("#nombredelservicio").val("");
            $("#campoServicioDescripcion").val("");
            $("#campoServicioCantidad").val("");

            idServicioGlobal="";
            skuServicioGlobal="";
            // fin de la limpieza


            var total = 0;
            var neto = 0;

            // alert(activardescuento);

            $.each(resultadoServiciosSeleccionados, function(index, objeto) {


                objeto.total = objeto.precio_neto * objeto.cantidad;



                total = total + objeto.total;
                neto = neto + objeto.precio_neto * objeto.cantidad;

                if (objeto.descripcion === null) {
                objeto.descripcion = "";
                }


                var tr = "<tr>";
                tr += "<td>" + (objeto.sku || '').toUpperCase() + "</td>";
                tr += "<td>" + (objeto.nombre_servicio || '').toUpperCase() + "</td>";
                // tr += "<td class='text-uppercase' >" + (objeto.descripcion || '') + "</td>";
                tr += "<td>" + "<input type='text' value='"+objeto.descripcion+"' onchange='agregarDescripcion("+objeto.id+",this)' >" + "</td>";
                tr += "<td>" + (objeto.nombre_categoria || '').toUpperCase() + "</td>";
                tr += "<td>" + "<input type='button' value='-'  onclick='restar(" + objeto.id + ")' >" +
                    "<input style='width: 40px' type='text' onchange='cambiodevalormanual(" + objeto.id +
                    ",this)' class='narrow-input' onkeypress='soloNumeros(event)' value='" + objeto.cantidad +
                    "' id='valores" + objeto
                    .id + "'>" + "<input type='button' onclick='sumar(" + objeto.id + ")'  value='+'>" + "</td>";

                    // if(objeto.precio_editable == 1 && (tipoUsuario == "superadmin" || tipoUsuario == "admin")  ){

                        if(objeto.precio_editable == 1 ){
                            tr += "<td>" + "<input type='number' onchange='cambiodevalormaPrecio(" + objeto.id +",this)'   value='"+objeto.precio_neto+"'>" + "</td>";

                        }else{
                            tr += "<td>" + formatNumberWithCommas(objeto.precio_neto) + "</td>";

                        }



                //  tr += "<td>" + 2+"</td>";
                tr += "<td>" + formatNumberWithCommas(objeto.total) + "</td>";
                tr += "<td>" + '<a  onclick="eliminarFilaServicio(' + objeto.id + ')"  >' + "Eliminar" + "</a>" +
                    "</td>";
                tr += "</tr>";
                $('#tabla_servicios_selecionados').append(tr);

            });
            $('#arrayDatosTabla').val(JSON.stringify(resultadoServiciosSeleccionados));


           





             //SUB TOTAL
              $("#l_subtotal").text(formatNumberWithCommas(neto));
              //
  
             //IMPUESTO AL SUBTOTAL 
              l_impuestoTotal = (neto * 19) / 100;
              $("#l_impuestoTotal").text(formatNumberWithCommas(l_impuestoTotal));
            ////

             //TOTAL MAS IMPUESTO
             l_totalmasimpuesto = neto + l_impuestoTotal;
             $("#l_totalmasimpuesto").text(formatNumberWithCommas(l_totalmasimpuesto));


             if(activardescuento != 0 || isActiveDescuentoEntero == true){

                    if(dscuentoTotalAplicadoT != 0){
                        console.log("entreee");
                        var paso_1 = dscuentoTotalAplicadoT * 100;
                        // var paso_2 = paso_1 / neto;
                        var paso_2 = parseFloat((paso_1 / l_totalmasimpuesto).toFixed(4));
                        $("#l_descuento_sin_porcentaje").text(formatNumberWithCommas(dscuentoTotalAplicadoT));
                        TotalPorcentajeDescuento  = paso_2

                        
                    }
                }
                
             //DESCUENTO POR PORCENTAJE
             var descuento = (l_totalmasimpuesto * TotalPorcentajeDescuento) / 100;

            //TOTAL CON DESCUENTOS
            l_totalcondescuento = l_totalmasimpuesto - descuento;
            $("#l_totalcondescuento").text(formatNumberWithCommas(l_totalcondescuento));

         
           getData = calcularIVA(l_totalcondescuento, 19);
           $("#l_totalnetoNuevo").text(formatNumberWithCommas( getData.neto));

            $("#l_impuestoTotalNuevo").text(formatNumberWithCommas( getData.impuesto));

            //PENDIENTE
            totalMenosDescuentos = l_totalcondescuento - totalAbono;
            $("#l_pendiente").text(formatNumberWithCommas(totalMenosDescuentos));


             




            //calculamos los totales

            // Calcular el descuento

            var descuentoSinPorcentaje = dscuentoTotalAplicadoT;


            // Calcular el nuevo precio después del descuento totalAbono
            var precioConDescuento = l_totalmasimpuesto - descuento;

            if(activardescuento == 0){

                
                
                $("#l_descuento_sin_porcentaje").text(formatNumberWithCommas(l_totalmasimpuesto-precioConDescuento));

           }


            //completamos los Label
         

            $("#l_descuento").text(TotalPorcentajeDescuento + "%");
            $("#l_descuentoTotal").text(formatNumberWithCommas(descuento));
            $("#l_abono").text(formatNumberWithCommas(totalAbono));

            // $("#l_descuentoTotal").text(formatNumberWithCommas(descuento));
    

         


         

            //setiamos los pagos para enviarlos por el formulario
            $("#input_abono").val(totalAbono);
            $("#input_descuento").val(TotalPorcentajeDescuento);
            $("#input_metodopago").val(metodoDePago);

            // console.log(resultadoServiciosSeleccionados);

        }

        function calcularIVA(valorBruto, tasaIVA) {
  // Convierte la tasa de IVA a un decimal dividiéndola por 100
  var tasaDecimal = (tasaIVA / 100) +1 ;

  // Calcula el monto del IVA
   neto = valorBruto / tasaDecimal;
    
   impuesto =  valorBruto- neto ;



   return {
    neto: neto,
    impuesto: impuesto
  };
}


        function selecionarEquipo(data) {
            $('#tableequipo').empty();

            $.each(arrayequipos, function(index, objeto) {
                if (objeto.id === data) {
                    $("#equipo_nombre").val(objeto.descripcion);
                    $("#equipo_modelo").val(objeto.modelo);
                    // $("#equipo_patente").val(objeto.patente);
                    $("#equipo_marca").val(objeto.marca);
                    $("#equipo_motor").val(objeto.motor);
                    $("#equipo_ano").val(objeto.ano);
                    $("#equipo_serie").val(objeto.serie);
                    $("#equipo_combustible").val(objeto.combustible_id);







                }
            });
        }

        function atras(atrases) {

            if (atrases == 1) {
                $("#datosequipo").css("display", "")
                $("#servivioyrepuestos").css("display", "none")
            }
            if (atrases == 2) {
                $("#servivioyrepuestos").css("display", "")
                $("#datoscontactose").css("display", "none")
            }


        }

        function siguiente(sess) {
// alert(sess);

            if (sess == 1) {

              
                // validamos los campos obligatorios en este caso
                if (
                    $("#sucursal").val() == "" ||
                    $("#equipo_modelo").val() == ""
                    // || $("#equipo_patente").val() == ""
                    ||
                    $("#equipo_marca").val() == "" ||
                    // $("#equipo_ano").val() == "" ||
                    $("#equipo_combustible").val() == ""
                    // || $("#equipo_responsable").val() == ""
                    ||
                    $("#equipo_marca").val() == ""

                ) {
                    // alert(1);
                    // Add a class to the input fields with missing data
                    if ($("#equipo_modelo").val() == "") {
                        $("#equipo_modelo").addClass("missing-field");
                    }
                    if($("#sucursal").val() == ""){
                    $("#sucursal").addClass("missing-field");
                }
                    
                    // if ($("#equipo_patente").val() == "") {
                    //     $("#equipo_patente").addClass("missing-field");
                    // }
                    if ($("#equipo_marca").val() == "") {
                        $("#equipo_marca").addClass("missing-field");
                    }
                    // if ($("#equipo_ano").val() == "") {
                    //     $("#equipo_ano").addClass("missing-field");
                    // }
                    if ($("#equipo_combustible").val() == "") {
                        $("#equipo_combustible").addClass("missing-field");
                    }
                    // if ($("#equipo_responsable").val() == "") {
                    //     $("#equipo_responsable").addClass("missing-field");
                    // }
                    // alert("ingrese todos los datos correspondientes");
                } else {
                    $("#datosequipo").css("display", "none")
                    $("#servivioyrepuestos").css("display", "")
                }

            }


            // sessioon dos
            if (sess == 2) {
                   if(resultadoServiciosSeleccionados.length <= 0){

                    $("#faltaServicio").css("display","");
                    return;
                   }
                   $("#faltaServicio").css("display","none");

                // servicioSeleccionado
                if (
                    // $("#operario").val() == "" ||
                   // $("#fecha_entrega").val() == "" ||
                    // $("#idcomentario").val() == "" ||
                    $("#sucursal").val() == "" ||

                    $("#equipo_modelo").val() == ""
                    // || $("#equipo_patente").val() == ""
                    ||
                    $("#equipo_marca").val() == "" ||
                    // $("#equipo_ano").val() == "" ||
                    $("#equipo_combustible").val() == ""
                    // || $("#equipo_responsable").val() == ""
                    ||
                    $("#equipo_marca").val() == ""


                    // || $("#arrayDatosTabla").val() == ""
                    //|| $("#arrayDatosTablaRepuestos").val() == ""
                ) {
                    if($("#sucursal").val() == ""){
                    $("#sucursal").addClass("missing-field");
                }
                    // if ($("#fecha_entrega").val() == "") {
                    //     $("#fecha_entrega").addClass("missing-field");
                    // }
                    // if ($("#operario").val() == "") {
                    //     $("#operario").addClass("missing-field");
                    // }
                    // if ($("#idcomentario").val() == "") {
                    //     $("#idcomentario").addClass("missing-field");
                    // }
                     // Add a class to the input fields with missing data
                     if ($("#equipo_modelo").val() == "") {
                        $("#equipo_modelo").addClass("missing-field");
                    }
                    // if ($("#equipo_patente").val() == "") {
                    //     $("#equipo_patente").addClass("missing-field");
                    // }
                    if ($("#equipo_marca").val() == "") {
                        $("#equipo_marca").addClass("missing-field");
                    }
                    // if ($("#equipo_ano").val() == "") {
                    //     $("#equipo_ano").addClass("missing-field");
                    // }
                    if ($("#equipo_combustible").val() == "") {
                        $("#equipo_combustible").addClass("missing-field");
                    }
                    // if ($("#equipo_responsable").val() == "") {
                    //     $("#equipo_responsable").addClass("missing-field");
                    // }
                    // alert("ingrese todos los datos correspondientes");
                    // alert("ingrese todos los datos correspondientes");
                } else {
                    $("#servivioyrepuestos").css("display", "none")
                    $("#datosequipo").css("display", "none")

                    $("#datoscontactose").css("display", "")
                }



            }

            // sessioon tres
            if (sess == 3) {

                $("#servivioyrepuestos").css("display", "none")
                $("#datoscontactose").css("display", "")

            }


        }
    </script>
    <style>
        .missing-field {
            border: 2px solid red;
        }
        .table-scroll {
    max-height: 300px; /* Altura máxima para el scroll vertical */
    overflow-y: auto;
}
    </style>
    <script>
        function validarFormulario() {
            var contadorError = 0;
         if(  $("#contacto_razon_social").val()  == ""){
                $("#l_contacto_razon_social").css("display","");
                contadorError = 1;
         }else{
            $("#l_contacto_razon_social").css("display","none");
         }

         if(  $("#contacto_rut").val()  == ""){
                $("#l_contacto_rut").css("display","");
                contadorError = 1;
         }else{
            $("#l_contacto_rut").css("display","none");
         }


        //  if(  $("#contacto_giro").val()  == ""){
        //         $("#l_contacto_giro").css("display","");
        //         contadorError = 1;
        //  }else{
        //     $("#l_contacto_giro").css("display","none");
        //  }

         if(  $("#contacto_telefono").val()  == ""){
                $("#l_contacto_telefono").css("display","");
                contadorError = 1;
         }else{
            $("#l_contacto_telefono").css("display","none");
         }

        //  if(  $("#contacto_correo").val()  == ""){
        //         $("#l_contacto_correo").css("display","");
        //         contadorError = 1;
        //  }else{
        //     $("#l_contacto_correo").css("display","none");
        //  }


         if(  $("#contacto_direccion").val()  == ""){
                $("#l_contacto_direccion").css("display","");
                contadorError = 1;
         }else{
            $("#l_contacto_direccion").css("display","none");
         }

         if(  $("#region").val()  == ""){
                $("#l_region").css("display","");
                contadorError = 1;
         }else{
            $("#l_region").css("display","none");
         }


         if(  $("#comuna").val()  == ""){
                $("#l_comuna").css("display","");
                contadorError = 1;
         }else{
            $("#l_comuna").css("display","none");
         }


         if(contadorError >= 1){
            return false;
         }else{
            $("#botonSiguiente").remove();
            $("#formulario_principal").css("display","none");
            return true;
         }

            
        }
    </script>

    <script>
        $(document).ready(function(){
            $("#contacto_razon_social").change(function(){
               var valor = $(this).val().trim(); // Aplicamos trim() al valor
            if(valor === ""){
                        $("#l_contacto_razon_social").css("display","");
                    }else{
                        $("#l_contacto_razon_social").css("display","none");
                    }
            });

            $("#contacto_rut").change(function(){
               var valor = $(this).val().trim(); // Aplicamos trim() al valor
             if(valor === ""){
                $("#v").css("display","");
               }else{
                $("#v").css("display","none");
               }
            });

            $("#contacto_giro").change(function(){
               var valor = $(this).val().trim(); // Aplicamos trim() al valor
             if(valor === ""){
                $("#l_contacto_giro").css("display","");
               }else{
                $("#l_contacto_giro").css("display","none");
               }
            });

            $("#contacto_telefono").change(function(){
               var valor = $(this).val().trim(); // Aplicamos trim() al valor
            if(valor === ""){
                 $("#l_contacto_telefono").css("display","");
               }else{
                $("#l_contacto_telefono").css("display","none");
               }
            });

          
            
            $("#contacto_direccion").change(function(){
               var valor = $(this).val().trim(); // Aplicamos trim() al valor
    if(valor === ""){
                $("#l_contacto_direccion").css("display","");
               }else{
                $("#l_contacto_direccion").css("display","none");
               }
            });

            $("#region").change(function(){
               var valor = $(this).val().trim(); // Aplicamos trim() al valor
    if(valor === ""){
                $("#l_region").css("display","");
               }else{
                $("#l_region").css("display","none");
               }
            });

            $("#comuna").change(function(){
               var valor = $(this).val().trim(); // Aplicamos trim() al valor
    if(valor === ""){
                $("#l_comuna").css("display","");
               }else{
                $("#l_comuna").css("display","none");
               }
            });

            $("#contacto_correo").change(function(){
               var valor = $(this).val().trim(); // Aplicamos trim() al valor
             if(valor === ""){
                $("#l_contacto_correo").css("display","");
               }else{
                $("#l_contacto_correo").css("display","none");
               }
            }); 
  
});
    </script>
@endsection
